==> dracula-cli-0.1.0.tar.gz: dracula-cli-0.1.0/README.md <==
# Dracula CLI

`dracula-cli` is [`draculatheme.org`](https://draculatheme.org) on the command line. It brings app information, installation guide, and other Website concepts to the terminal next to where you are already working with dracula and your code.

![](./screenshot.png)

## Installation

The easiest way to install `dracula-cli` is to install it with [pip](https://pypi.org/project/pip/ "pip is the package installer for Python."). Note that you'll need to have python version 3.6 or later installed. To install, run the following command in a terminal:

```sh
pip install dracula-cli
```

You may want to replace `pip` with `pip3` if this fails.

## Usage

> **Note:** There are several parameters you can tweak to change the behavior of the following commands

```sh
dracula view visual-studio-code
```

```sh
dracula all
```

## Documentation

The documentation is currently available at [DOCUMENTATION.md](https://github.com/dracula/dracula-cli/tree/master/DOCUMENTATION.md)

## Contributing

If anything feels off, or if you feel that some functionality is missing, please consider opening an issue or a pull request


## Team

This theme is maintained by the following person(s) and a bunch of [awesome contributors](https://github.com/dracula/dracula-cli/graphs/contributors).

| [![Wasi Master](https://github.com/wasi-master.png)](https://github.com/wasi-master) |
| --------------------------------------------------------------------------------------------------------------- |
| [Wasi Master](https://github.com/wasi-master)                                                            |

## License

[MIT License](./LICENSE)

==> dracula-cli-0.1.2.tar.gz: dracula-cli-0.1.2/README.md <==
# Dracula CLI

`dracula-cli` is [`draculatheme.org`](https://draculatheme.org) on the command line. It brings app information, installation guide, and other Website concepts to the terminal next to where you are already working with dracula and your code.

![](./screenshot.png)

## Installation

The easiest way to install `dracula-cli` is to install it with [pip](https://pypi.org/project/pip/ "pip is the package installer for Python."). Note that you'll need to have [python](https://python.org "Python is a high-level, general-purpose programming language.") version 3.6 or later installed. To install, run the following command in a terminal:

```sh
pip install dracula-cli
```

You may want to replace `pip` with `pip3` if this fails.

## Usage

> **Note:** There are several parameters you can tweak to change the behavior of the following commands

```sh
dracula view visual-studio-code
```

```sh
dracula all
```

## Documentation

The documentation is currently available at [DOCUMENTATION.md](https://github.com/dracula/dracula-cli/tree/master/DOCUMENTATION.md)

## Contributing

If anything feels off, or if you feel that some functionality is missing, please consider opening an issue or a pull request. See [TODO.md](https://github.com/dracula/dracula-cli/blob/main/TODO.md) for inspiration


## Team

This theme is maintained by the following person(s) and a bunch of [awesome contributors](https://github.com/dracula/dracula-cli/graphs/contributors).

| [![Wasi Master](https://github.com/wasi-master.png)](https://github.com/wasi-master) |
| --------------------------------------------------------------------------------------------------------------- |
| [Wasi Master](https://github.com/wasi-master)                                                            |

## License

[MIT License](./LICENSE)
